<template>
	<div class="bbsl-common-page">
		<div class="bbsl-table-search">
			<el-form v-model="queryParam" label-width="auto">
				<el-row :gutter="10">
					<el-col :span="5">
						<el-form-item label="单位名称">
							<el-input maxlength="128" clearable placeholder="请输入单位名称"
								v-model="querys[0].value"></el-input>
						</el-form-item>
					</el-col>
					<el-col :span="5">
						<el-form-item label="单位类型">
							<el-select v-model="companyTypeValue" multiple clearable placeholder="请选择单位类型">
								<el-option v-for="item in companyType" :key="item.value" :label="item.name"
									:value="item.value">
								</el-option>
							</el-select>
						</el-form-item>
					</el-col>
					<el-col :span="4">
						<el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
						<el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
					</el-col>
				</el-row>
			</el-form>
		</div>
		<div class="bbsl-table-content" ref="contentPanel">
			<div class="bbsl-btn-content" ref="btnPanel">
				<el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
				<el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
					<el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
						type="danger" style="margin-left: 10px">删除</el-button>
				</el-popconfirm>
			</div>
			<el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
				:style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
				:header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
				@selection-change="handleSelectionChange">
				<el-table-column type="selection" width="55"></el-table-column>
				<el-table-column fixed type="index" width="55" label="序号"></el-table-column>
				<el-table-column min-width="160" fixed prop="companyShortName" label="单位简称"
					show-overflow-tooltip></el-table-column>
				<el-table-column fixed min-width="200" prop="companyName" label="单位名称" show-overflow-tooltip>
				</el-table-column>
				<el-table-column prop="companyCode" label="单位编码" show-overflow-tooltip></el-table-column>
				<el-table-column min-width="120" prop="companyTypeShow" label="单位类型" show-overflow-tooltip>
					<template slot-scope="scope">
						<el-tag class="type-tag" v-for="(type, index) in scope.row.companyTypeShow" :key="index"
							type="success">{{ type }}</el-tag>
					</template>
				</el-table-column>
				<el-table-column min-width="150" prop="companyAddress" label="单位地址"
					show-overflow-tooltip></el-table-column>
				<el-table-column min-width="100" prop="companyMan" label="联系人" show-overflow-tooltip></el-table-column>
				<el-table-column width="150" prop="companyTel" label="联系电话" show-overflow-tooltip></el-table-column>
			</el-table>
			<el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
				@size-change="handleSizeChange" @current-change="handleCurrentChange"
				:current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
				:page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
				:total="total"></el-pagination>
		</div>
		<unit-manage-dialog ref="formModal"></unit-manage-dialog>
	</div>
</template>


<script>
import {
	TableMixin
} from '@/mixins/tableMixin'
import unitManageDialog from '@/views/Device/resourceManage/components/unitManageDialog'
import resourceManage from '@/api/device/resourceManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
export default {
	name: 'UnitManage',
	components: {
		unitManageDialog,
	},
	mixins: [TableMixin],
	data() {
		return {
			url: {
				delete: '/device/base/company/',
			},
			companyType: [],
			companyTypeValue: [],
			querys: [{
				group: 'main',
				operation: 'LIKE',
				parentGroup: '',
				property: 'companyName',
				relation: 'AND',
				value: '',
			},
			{
				group: 'main',
				operation: 'LIKE',
				parentGroup: '',
				property: 'companyType',
				relation: 'AND',
				value: '',
			},
			],
		}
	},
	created() {
		this.companyType = dictUtils.getDictItemsFromCache('dwlx')
	},
	mounted() { },
	methods: {
		formatData(rows) {
			rows.forEach((row) => {
				let types = row.companyType.split(',')
				let temp = types.map((item) => {
					let name
					this.companyType.forEach((dictItem) => {
						if (dictItem.value == item) {
							name = dictItem.name
						}
					})
					return name
				})
				row.companyTypeShow = temp
			})
			return rows
		},
		clearQuerys() {
			this.querys[0].value = ''
			this.companyTypeValue = []
		},
		loadData(page) {
			if (page) {
				this.queryParam.pageBean.page = page
			}
			this.loading = true
			this.tableData = []
			this.queryParam.querys = []
			if (this.querys[0].value) {
				this.queryParam.querys.push(this.querys[0])
			}
			if (this.companyTypeValue.length) {
				this.querys[1].value = this.companyTypeValue.join(',')
				this.queryParam.querys.push(this.querys[1])
			}
			resourceManage.loadUnit(this.queryParam, (res) => {
				// console.log(res, 'res')
				this.total = res.total
				this.tableData = this.formatData(res.rows)
				this.$set(this.tableData)
				this.loading = false
			})
		},
	},
}
</script>
<style lang="scss" scoped>
.type-tag {
	margin: 0 2px;
}
</style>
